Aurora modules
==========

Submodules
-------------------


aurora.core module
-----------------------------

.. automodule:: aurora.core
    :members:
    :undoc-members:
    :show-inheritance:


aurora.atomic module
---------------------------------

.. automodule:: aurora.atomic
    :members:
    :undoc-members:
    :show-inheritance:

       
aurora.adas_files module
--------------------------------------

.. automodule:: aurora.adas_files
    :members:
    :undoc-members:
    :show-inheritance:


aurora.radiation module
------------------------------------

.. automodule:: aurora.radiation
    :members:
    :undoc-members:
    :show-inheritance:


aurora.grids_utils module
---------------------------------------

.. automodule:: aurora.grids_utils
    :members:
    :undoc-members:
    :show-inheritance:


aurora.coords module
---------------------------------

.. automodule:: aurora.coords
    :members:
    :undoc-members:
    :show-inheritance:


aurora.source_utils module
-----------------------------------------

.. automodule:: aurora.source_utils
    :members:
    :undoc-members:
    :show-inheritance:


aurora.plot_tools module
--------------------------------------

.. automodule:: aurora.plot_tools
    :members:
    :undoc-members:
    :show-inheritance:


aurora.default_nml module
-----------------------------------------

.. automodule:: aurora.default_nml
    :members:
    :undoc-members:
    :show-inheritance:


aurora.interp module
--------------------------------

.. automodule:: aurora.interp
    :members:
    :undoc-members:
    :show-inheritance:


aurora.animate module
------------------------------------

.. automodule:: aurora.animate
    :members:
    :undoc-members:
    :show-inheritance:


aurora.particle_conserv module
------------------------------------------------

.. automodule:: aurora.particle_conserv
    :members:
    :undoc-members:
    :show-inheritance:


aurora.neutrals module
------------------------------------

.. automodule:: aurora.neutrals
    :members:
    :undoc-members:
    :show-inheritance:


aurora.nbi_neutrals module
------------------------------------------

.. automodule:: aurora.nbi_neutrals
    :members:
    :undoc-members:
    :show-inheritance:


aurora.janev_smith_rates module
---------------------------------------------------

.. automodule:: aurora.janev_smith_rates
    :members:
    :undoc-members:
    :show-inheritance:


aurora.synth_diags module
------------------------------------------

.. automodule:: aurora.synth_diags
    :members:
    :undoc-members:
    :show-inheritance:

       
aurora.kn1d module
-------------------------------

.. automodule:: aurora.kn1d
    :members:
    :undoc-members:
    :show-inheritance:


aurora.solps module
-------------------------------

.. automodule:: aurora.solps
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
-------------------------

.. automodule:: aurora
    :members:
    :undoc-members:
    :show-inheritance:
